pb

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2026 License: MPL-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

const (
	BindingService_Bind_FullMethodName   = "/contract.BindingService/Bind"
	BindingService_Unbind_FullMethodName = "/contract.BindingService/Unbind"
)
const (
	QueueService_CreateQueue_FullMethodName = "/contract.QueueService/CreateQueue"
	QueueService_DeleteQueue_FullMethodName = "/contract.QueueService/DeleteQueue"
)
const (
	ExchangeService_CreateExchange_FullMethodName = "/contract.ExchangeService/CreateExchange"
)

Variables

var BindingService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "contract.BindingService",
	HandlerType: (*BindingServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Bind",
			Handler:    _BindingService_Bind_Handler,
		},
		{
			MethodName: "Unbind",
			Handler:    _BindingService_Unbind_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "Binding.proto",
}

BindingService_ServiceDesc is the grpc.ServiceDesc for BindingService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var ExchangeService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "contract.ExchangeService",
	HandlerType: (*ExchangeServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateExchange",
			Handler:    _ExchangeService_CreateExchange_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "Exchange.proto",
}

ExchangeService_ServiceDesc is the grpc.ServiceDesc for ExchangeService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_Binding_proto protoreflect.FileDescriptor
var File_Error_proto protoreflect.FileDescriptor
var File_Exchange_proto protoreflect.FileDescriptor
var File_Queue_proto protoreflect.FileDescriptor
var QueueService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "contract.QueueService",
	HandlerType: (*QueueServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateQueue",
			Handler:    _QueueService_CreateQueue_Handler,
		},
		{
			MethodName: "DeleteQueue",
			Handler:    _QueueService_DeleteQueue_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "Queue.proto",
}

QueueService_ServiceDesc is the grpc.ServiceDesc for QueueService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterBindingServiceServer

func RegisterBindingServiceServer(s grpc.ServiceRegistrar, srv BindingServiceServer)

func RegisterExchangeServiceServer

func RegisterExchangeServiceServer(s grpc.ServiceRegistrar, srv ExchangeServiceServer)

func RegisterQueueServiceServer

func RegisterQueueServiceServer(s grpc.ServiceRegistrar, srv QueueServiceServer)

Types

type Binding

type Binding struct {
	Queue      string `protobuf:"bytes,1,opt,name=queue,proto3" json:"queue,omitempty"`
	Exchange   string `protobuf:"bytes,2,opt,name=exchange,proto3" json:"exchange,omitempty"`
	RoutingKey string `protobuf:"bytes,3,opt,name=routing_key,json=routingKey,proto3" json:"routing_key,omitempty"`
	// contains filtered or unexported fields
}

func (*Binding) Descriptor deprecated

func (*Binding) Descriptor() ([]byte, []int)

Deprecated: Use Binding.ProtoReflect.Descriptor instead.

func (*Binding) GetExchange

func (x *Binding) GetExchange() string

func (*Binding) GetQueue

func (x *Binding) GetQueue() string

func (*Binding) GetRoutingKey

func (x *Binding) GetRoutingKey() string

func (*Binding) ProtoMessage

func (*Binding) ProtoMessage()

func (*Binding) ProtoReflect

func (x *Binding) ProtoReflect() protoreflect.Message

func (*Binding) Reset

func (x *Binding) Reset()

func (*Binding) String

func (x *Binding) String() string

type BindingServiceClient

type BindingServiceClient interface {
	Bind(ctx context.Context, in *Binding, opts ...grpc.CallOption) (*Error, error)
	Unbind(ctx context.Context, in *Binding, opts ...grpc.CallOption) (*Error, error)
}

BindingServiceClient is the client API for BindingService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type BindingServiceServer

type BindingServiceServer interface {
	Bind(context.Context, *Binding) (*Error, error)
	Unbind(context.Context, *Binding) (*Error, error)
	// contains filtered or unexported methods
}

BindingServiceServer is the server API for BindingService service. All implementations must embed UnimplementedBindingServiceServer for forward compatibility.

type Error

type Error struct {
	Error *string `protobuf:"bytes,1,opt,name=error,proto3,oneof" json:"error,omitempty"`
	// contains filtered or unexported fields
}

func (*Error) Descriptor deprecated

func (*Error) Descriptor() ([]byte, []int)

Deprecated: Use Error.ProtoReflect.Descriptor instead.

func (*Error) GetError

func (x *Error) GetError() string

func (*Error) ProtoMessage

func (*Error) ProtoMessage()

func (*Error) ProtoReflect

func (x *Error) ProtoReflect() protoreflect.Message

func (*Error) Reset

func (x *Error) Reset()

func (*Error) String

func (x *Error) String() string

type Exchange

type Exchange struct {
	Name        string                `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Type        string                `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
	Durable     *bool                 `protobuf:"varint,3,opt,name=durable,proto3,oneof" json:"durable,omitempty"`
	AutoDeleted *bool                 `protobuf:"varint,4,opt,name=auto_deleted,json=autoDeleted,proto3,oneof" json:"auto_deleted,omitempty"`
	Internal    *bool                 `protobuf:"varint,5,opt,name=internal,proto3,oneof" json:"internal,omitempty"`
	NoWait      *bool                 `protobuf:"varint,6,opt,name=no_wait,json=noWait,proto3,oneof" json:"no_wait,omitempty"`
	Args        map[string]*anypb.Any `` /* 135-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*Exchange) Descriptor deprecated

func (*Exchange) Descriptor() ([]byte, []int)

Deprecated: Use Exchange.ProtoReflect.Descriptor instead.

func (*Exchange) GetArgs

func (x *Exchange) GetArgs() map[string]*anypb.Any

func (*Exchange) GetAutoDeleted

func (x *Exchange) GetAutoDeleted() bool

func (*Exchange) GetDurable

func (x *Exchange) GetDurable() bool

func (*Exchange) GetInternal

func (x *Exchange) GetInternal() bool

func (*Exchange) GetName

func (x *Exchange) GetName() string

func (*Exchange) GetNoWait

func (x *Exchange) GetNoWait() bool

func (*Exchange) GetType

func (x *Exchange) GetType() string

func (*Exchange) ProtoMessage

func (*Exchange) ProtoMessage()

func (*Exchange) ProtoReflect

func (x *Exchange) ProtoReflect() protoreflect.Message

func (*Exchange) Reset

func (x *Exchange) Reset()

func (*Exchange) String

func (x *Exchange) String() string

type ExchangeServiceClient

type ExchangeServiceClient interface {
	CreateExchange(ctx context.Context, in *Exchange, opts ...grpc.CallOption) (*Error, error)
}

ExchangeServiceClient is the client API for ExchangeService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type ExchangeServiceServer

type ExchangeServiceServer interface {
	CreateExchange(context.Context, *Exchange) (*Error, error)
	// contains filtered or unexported methods
}

ExchangeServiceServer is the server API for ExchangeService service. All implementations must embed UnimplementedExchangeServiceServer for forward compatibility.

type Queue

type Queue struct {
	Name         string                `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Durable      *bool                 `protobuf:"varint,2,opt,name=durable,proto3,oneof" json:"durable,omitempty"`
	DeleteUnused *bool                 `protobuf:"varint,3,opt,name=delete_unused,json=deleteUnused,proto3,oneof" json:"delete_unused,omitempty"`
	Exclusive    *bool                 `protobuf:"varint,4,opt,name=exclusive,proto3,oneof" json:"exclusive,omitempty"`
	NoWait       *bool                 `protobuf:"varint,5,opt,name=no_wait,json=noWait,proto3,oneof" json:"no_wait,omitempty"`
	Args         map[string]*anypb.Any `` /* 135-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*Queue) Descriptor deprecated

func (*Queue) Descriptor() ([]byte, []int)

Deprecated: Use Queue.ProtoReflect.Descriptor instead.

func (*Queue) GetArgs

func (x *Queue) GetArgs() map[string]*anypb.Any

func (*Queue) GetDeleteUnused

func (x *Queue) GetDeleteUnused() bool

func (*Queue) GetDurable

func (x *Queue) GetDurable() bool

func (*Queue) GetExclusive

func (x *Queue) GetExclusive() bool

func (*Queue) GetName

func (x *Queue) GetName() string

func (*Queue) GetNoWait

func (x *Queue) GetNoWait() bool

func (*Queue) ProtoMessage

func (*Queue) ProtoMessage()

func (*Queue) ProtoReflect

func (x *Queue) ProtoReflect() protoreflect.Message

func (*Queue) Reset

func (x *Queue) Reset()

func (*Queue) String

func (x *Queue) String() string

type QueueServiceClient

type QueueServiceClient interface {
	CreateQueue(ctx context.Context, in *Queue, opts ...grpc.CallOption) (*Error, error)
	DeleteQueue(ctx context.Context, in *Queue, opts ...grpc.CallOption) (*Error, error)
}

QueueServiceClient is the client API for QueueService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type QueueServiceServer

type QueueServiceServer interface {
	CreateQueue(context.Context, *Queue) (*Error, error)
	DeleteQueue(context.Context, *Queue) (*Error, error)
	// contains filtered or unexported methods
}

QueueServiceServer is the server API for QueueService service. All implementations must embed UnimplementedQueueServiceServer for forward compatibility.

type UnimplementedBindingServiceServer

type UnimplementedBindingServiceServer struct{}

UnimplementedBindingServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedBindingServiceServer) Bind

func (UnimplementedBindingServiceServer) Unbind

type UnimplementedExchangeServiceServer

type UnimplementedExchangeServiceServer struct{}

UnimplementedExchangeServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedExchangeServiceServer) CreateExchange

type UnimplementedQueueServiceServer

type UnimplementedQueueServiceServer struct{}

UnimplementedQueueServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedQueueServiceServer) CreateQueue

func (UnimplementedQueueServiceServer) DeleteQueue

type UnsafeBindingServiceServer

type UnsafeBindingServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeBindingServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to BindingServiceServer will result in compilation errors.

type UnsafeExchangeServiceServer

type UnsafeExchangeServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeExchangeServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ExchangeServiceServer will result in compilation errors.

type UnsafeQueueServiceServer

type UnsafeQueueServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeQueueServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to QueueServiceServer will result in compilation errors.

Jump to